
Status
------

Problematic
^^^^^^^^^^^

How can we gather, manage and provide a status for a given subject ?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.status
   :members:
   :private-members:

:code:`GathererBase()`
""""""""""""""""""""""

.. autoclass:: PyFunceble.status.gatherer_base.GathererBase
    :members:
    :private-members:

:code:`Status()`
""""""""""""""""

.. autoclass:: PyFunceble.status.status.Status
    :members:
    :private-members:

Availability: :code:`DomainAndIp()`
"""""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.availability.domain_and_ip.DomainAndIp
    :members:
    :private-members:

Availability: :code:`ExtraRules()`
""""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.availability.extra_rules.ExtraRules
    :members:
    :private-members:

Availability: :code:`Url()`
"""""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.availability.url.Url
    :members:
    :private-members:

Reputation: :code:`DomainAndIp()`
"""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.reputation.domain_and_ip.DomainAndIp
    :members:
    :private-members:

Reputation: :code:`Url()`
"""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.reputation.url.Url
    :members:
    :private-members:

Syntax: :code:`DomainAndIp()`
"""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.status.syntax.domain_and_ip.DomainAndIp
    :members:
    :private-members:

Syntax: :code:`Url()`
"""""""""""""""""""""

.. autoclass:: PyFunceble.status.syntax.url.Url
    :members:
    :private-members: